@@ -57,6 +57,7 @@ namespace Banshee.PlaybackController
         private bool transition_track_started = false;
         private int consecutive_errors;
         private uint error_transition_id;
+        private DateTime source_auto_set_at = DateTime.MinValue;
     
         private PlaybackShuffleMode shuffle_mode;
         private PlaybackRepeatMode repeat_mode;
@@ -90,6 +91,14 @@ namespace Banshee.PlaybackController
                 PlayerEvent.StateChange |
                 PlayerEvent.Error, 
                 true);
+
+            ServiceManager.SourceManager.ActiveSourceChanged += delegate {
+                ITrackModelSource active_source = ServiceManager.SourceManager.ActiveSource as ITrackModelSource;
+                if (active_source != null && source_auto_set_at == source_set_at && !player_engine.IsPlaying ()) {
+                    Source = active_source;
+                    source_auto_set_at = source_set_at;
+                }
+            };
         }
         
         protected virtual void InstantiateStacks ()
@@ -100,7 +109,15 @@ namespace Banshee.PlaybackController
         
         private void OnPlayerEnginePlayWhenIdleRequest (object o, EventArgs args)
         {
-            Next ();
+            ITrackModelSource next_source = NextSource;
+            if (next_source != null && next_source.TrackModel.Selection.Count > 0) {
+                Source = NextSource;
+                CancelErrorTransition ();
+                CurrentTrack = next_source.TrackModel[next_source.TrackModel.Selection.FirstIndex];
+                QueuePlayTrack ();
+            } else {
+                Next ();
+            }
         }
         
         private void OnPlayerEvent (PlayerEventArgs args)
@@ -111,9 +128,9 @@ namespace Banshee.PlaybackController
                     break;
                 case PlayerEvent.EndOfStream:
                     EosTransition ();
-                       break;
+                    break;
                 case PlayerEvent.Error:
-                    if (++consecutive_errors >= 20) {
+                    if (++consecutive_errors >= 5) {
                         consecutive_errors = 0;
                         player_engine.Close (false);
                         OnStopped ();
@@ -121,6 +138,7 @@ namespace Banshee.PlaybackController
                     }
                     
                     CancelErrorTransition ();
+                    // TODO why is this so long? any reason not to be instantaneous?
                     Application.RunTimeout (500, EosTransition);
                     break;
                 case PlayerEvent.StateChange:
@@ -384,7 +402,7 @@ namespace Banshee.PlaybackController
             protected set { current_track = value; }
         }
         
-        protected DateTime source_set_at;
+        protected DateTime source_set_at = DateTime.MinValue;
         public ITrackModelSource Source {
             get { 
                 if (source == null && ServiceManager.SourceManager.DefaultSource is ITrackModelSource) {
