@@ -38,31 +38,45 @@ using Hyena.Query;
 
 namespace Banshee.Query
 {
+    /*public interface IQueryDefines
+    {
+        QueryOrder [] Orders { get; }
+        QueryLimit [] Limits { get; }
+        QueryFieldSet FieldSet { get; }
+        string GetSqlSort (string key, bool asc);
+    }
+    
+    public class QueryDefines : IQueryDefines
+    {
+        
+    }*/
+    
     public static class BansheeQuery
     {
         private static bool asc = true;
         private static bool desc = false;
 
-        public static QueryOrder RandomOrder = CreateQueryOrder ("Random",     asc,  Catalog.GetString ("Random"));
+        public static QueryOrder RandomOrder = CreateQueryOrder ("Random",     asc,  Catalog.GetString ("Random"), null);
 
         public static QueryOrder [] Orders = new QueryOrder [] {
             RandomOrder,
-            CreateQueryOrder ("Album",      asc,  Catalog.GetString ("Album")),
-            CreateQueryOrder ("Artist",     asc,  Catalog.GetString ("Artist")),
-            CreateQueryOrder ("Title",      asc,  Catalog.GetString ("Title")),
-            CreateQueryOrder ("Genre",      asc,  Catalog.GetString ("Genre")),
+            CreateQueryOrder ("Album",      asc,  Catalog.GetString ("Album"), AlbumField),
+            CreateQueryOrder ("Artist",     asc,  Catalog.GetString ("Artist"), ArtistField),
+            // Translators: noun
+            CreateQueryOrder ("Title",      asc,  Catalog.GetString ("Title"), TitleField),
+            CreateQueryOrder ("Genre",      asc,  Catalog.GetString ("Genre"), GenreField),
             null,
-            CreateQueryOrder ("Rating",     desc, Catalog.GetString ("Highest Rating")),
-            CreateQueryOrder ("Rating",     asc,  Catalog.GetString ("Lowest Rating")),
+            CreateQueryOrder ("Rating",     desc, Catalog.GetString ("Highest Rating"), RatingField),
+            CreateQueryOrder ("Rating",     asc,  Catalog.GetString ("Lowest Rating"), RatingField),
             null,
-            CreateQueryOrder ("PlayCount",  desc, Catalog.GetString ("Most Often Played")),
-            CreateQueryOrder ("PlayCount",  asc,  Catalog.GetString ("Least Often Played")),
+            CreateQueryOrder ("PlayCount",  desc, Catalog.GetString ("Most Often Played"), PlayCountField),
+            CreateQueryOrder ("PlayCount",  asc,  Catalog.GetString ("Least Often Played"), PlayCountField),
             null,
-            CreateQueryOrder ("LastPlayedStamp", desc, Catalog.GetString ("Most Recently Played")),
-            CreateQueryOrder ("LastPlayedStamp", asc,  Catalog.GetString ("Least Recently Played")),
+            CreateQueryOrder ("LastPlayedStamp", desc, Catalog.GetString ("Most Recently Played"), LastPlayedField),
+            CreateQueryOrder ("LastPlayedStamp", asc,  Catalog.GetString ("Least Recently Played"), LastPlayedField),
             null,
-            CreateQueryOrder ("DateAddedStamp",  desc, Catalog.GetString ("Most Recently Added")),
-            CreateQueryOrder ("DateAddedStamp",  asc,  Catalog.GetString ("Least Recently Added"))
+            CreateQueryOrder ("DateAddedStamp",  desc, Catalog.GetString ("Most Recently Added"), DateAddedField),
+            CreateQueryOrder ("DateAddedStamp",  asc,  Catalog.GetString ("Least Recently Added"), DateAddedField)
         };
 
         public static QueryLimit [] Limits = new QueryLimit [] {
@@ -72,144 +86,241 @@ namespace Banshee.Query
             new QueryLimit ("MB",      Catalog.GetString ("MB"), "CoreTracks.FileSize", (int) FileSizeFactor.MB),
             new QueryLimit ("GB",      Catalog.GetString ("GB"), "CoreTracks.FileSize", (int) FileSizeFactor.GB)
         };
+        
+#region QueryField Definitions
 
         public static QueryField ArtistField = new QueryField (
-            "artist", Catalog.GetString ("Artist"), "CoreArtists.NameLowered", true,
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            "artist", "ArtistName",
+            Catalog.GetString ("Artist"), "CoreArtists.NameLowered", true,
+            // Translators: These are unique search aliases for "artist".  Please, no spaces. Blank ok.
             Catalog.GetString ("artist"), Catalog.GetString ("by"), Catalog.GetString ("artists"),
             "by", "artist", "artists"
         );
 
+        public static QueryField AlbumArtistField = new QueryField (
+            "albumartist", "AlbumArtist",
+            Catalog.GetString ("Album Artist"), "CoreAlbums.ArtistNameLowered", true,
+            // Translators: These are unique search aliases for "album".  Please, no spaces. Blank ok.
+            Catalog.GetString ("albumartist"), Catalog.GetString ("compilationartist"),
+            "albumartist", "compilationartist"
+        );
+
+        // TODO add IsCompilationField
+
         public static QueryField AlbumField = new QueryField (
-            "album", Catalog.GetString ("Album"), "CoreAlbums.TitleLowered", true,
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            "album", "AlbumTitle",
+            Catalog.GetString ("Album"), "CoreAlbums.TitleLowered", true,
+            // Translators: These are unique search aliases for "album".  Please, no spaces. Blank ok.
             Catalog.GetString ("album"), Catalog.GetString ("on"), Catalog.GetString ("from"),
             "on", "album", "from", "albumtitle"
         );
 
         public static QueryField DiscField = new QueryField (
-            "disc", Catalog.GetString ("Disc"), "CoreTracks.Disc", typeof(NaturalIntegerQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            "disc", "DiscNumber",
+            Catalog.GetString ("Disc"), "CoreTracks.Disc", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("disc"), Catalog.GetString ("cd"), Catalog.GetString ("discnum"),
             "disc", "cd", "discnum"
         );
 
+        public static QueryField DiscCountField = new QueryField (
+            "disccount", "DiscCount",
+            Catalog.GetString ("Disc Count"), "CoreTracks.DiscCount", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
+            Catalog.GetString ("discs"), Catalog.GetString ("cds"),
+            "discs", "cds"
+        );
+        
+        public static QueryField TrackNumberField = new QueryField (
+            "track", "TrackNumber",
+            // Translators: noun
+            Catalog.GetString ("Track"), "CoreTracks.TrackNumber", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            "#", Catalog.GetString ("track"), Catalog.GetString ("trackno"), Catalog.GetString ("tracknum"),
+            "track", "trackno", "tracknum"
+        );
+
+        public static QueryField TrackCountField = new QueryField (
+            "trackcount", "TrackCount",
+            // Translators: noun
+            Catalog.GetString ("Track Count"), "CoreTracks.TrackCount", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("tracks"), Catalog.GetString ("trackcount"),
+            "tracks", "trackcount"
+        );
+
+        public static QueryField BpmField = new QueryField (
+            "bpm", "Bpm",
+            // Translators: noun
+            Catalog.GetString ("BPM"), "CoreTracks.BPM", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("bpm"),
+            "bpm"
+        );
+
+        public static QueryField BitRateField = new QueryField (
+            "bitrate", "BitRate",
+            // Translators: noun
+            Catalog.GetString ("Bit Rate"), "CoreTracks.BitRate", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("bitrate"), Catalog.GetString ("kbs"), Catalog.GetString ("kps"),
+            "bitrate", "kbs", "kps"
+        );
+
         public static QueryField TitleField = new QueryField (
-            "title", Catalog.GetString ("Track Title"), "CoreTracks.TitleLowered", true,
+            "title", "TrackTitle",
+            Catalog.GetString ("Title"), "CoreTracks.TitleLowered", true,
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("title"), Catalog.GetString ("titled"), Catalog.GetString ("name"), Catalog.GetString ("named"),
             "title", "titled", "name", "named"
         );
 
         public static QueryField YearField = new QueryField (
-            "year", Catalog.GetString ("Year"), "CoreTracks.Year", typeof(YearQueryValue),
+            "year", "Year",
+            Catalog.GetString ("Year"), "CoreTracks.Year", typeof(YearQueryValue),
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("year"), Catalog.GetString ("released"), Catalog.GetString ("yr"),
             "year", "released", "yr"
         );
 
         public static QueryField GenreField = new QueryField (
-            "genre", Catalog.GetString ("Genre"), "CoreTracks.Genre", false,
+            "genre", "Genre",
+            Catalog.GetString ("Genre"), "CoreTracks.Genre", false,
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("genre"), "genre"
         );
 
         public static QueryField ComposerField = new QueryField (
-            "composer", Catalog.GetString ("Composer"), "CoreTracks.Composer", false,
+            "composer", "Composer",
+            Catalog.GetString ("Composer"), "CoreTracks.Composer", false,
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("composer"), "composer"
         );
 
+        public static QueryField ConductorField = new QueryField (
+            "conductor", "Conductor",
+            Catalog.GetString ("Conductor"), "CoreTracks.Conductor", false,
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("conductor"), "conductor"
+        );
+
+        public static QueryField GroupingField = new QueryField (
+            "grouping", "Grouping",
+            Catalog.GetString ("Grouping"), "CoreTracks.Grouping", false,
+            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            Catalog.GetString ("grouping"), "grouping"
+        );
+
+        public static QueryField CommentField = new QueryField (
+            "comment", "Comment",
+            // Translators: noun
+            Catalog.GetString ("Comment"), "CoreTracks.Comment", false,
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
+            Catalog.GetString ("comment"), "comment"
+        );
+
         public static QueryField RatingField = new QueryField (
-            "rating", Catalog.GetString ("Rating"), "CoreTracks.Rating", new Type [] {typeof(RatingQueryValue)},//, typeof(NullQueryValue)},
+            "rating", "SavedRating",
+            Catalog.GetString ("Rating"), "CoreTracks.Rating", new Type [] {typeof(RatingQueryValue)},//, typeof(NullQueryValue)},
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("rating"), Catalog.GetString ("stars"),
             "rating", "stars"
         );
 
         public static QueryField PlayCountField = new QueryField (
-            "playcount", Catalog.GetString ("Play Count"), "CoreTracks.PlayCount", typeof(NaturalIntegerQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            "playcount", "PlayCount",
+            Catalog.GetString ("Play Count"), "CoreTracks.PlayCount", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("plays"), Catalog.GetString ("playcount"), Catalog.GetString ("listens"),
             "plays", "playcount", "numberofplays", "listens"
         );
 
         public static QueryField SkipCountField = new QueryField (
-            "skipcount", Catalog.GetString ("Skip Count"), "CoreTracks.SkipCount", typeof(NaturalIntegerQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            "skipcount", "SkipCount",
+            Catalog.GetString ("Skip Count"), "CoreTracks.SkipCount", typeof(NaturalIntegerQueryValue),
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("skips"), Catalog.GetString ("skipcount"),
             "skips", "skipcount"
         );
 
         public static QueryField FileSizeField = new QueryField (
-            "filesize", Catalog.GetString ("File Size"), "CoreTracks.FileSize", typeof(FileSizeQueryValue),
-            // Translators: These are unique search fields.  Please, no spaces. Blank ok.
+            "filesize", "FileSize",
+            Catalog.GetString ("File Size"), "CoreTracks.FileSize", typeof(FileSizeQueryValue),
+            // Translators: These are unique search fields (and nouns).  Please, no spaces. Blank ok.
             Catalog.GetString ("size"), Catalog.GetString ("filesize"),
             "size", "filesize"
         );
 
         public static QueryField UriField = new QueryField (
-            "uri", Catalog.GetString ("File Location"), "CoreTracks.Uri",
+            "uri", "Uri",
+            Catalog.GetString ("File Location"), "CoreTracks.Uri",
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("uri"), Catalog.GetString ("path"), Catalog.GetString ("file"), Catalog.GetString ("location"),
             "uri", "path", "file", "location"
         );
 
         public static QueryField DurationField = new QueryField (
-            "duration", Catalog.GetString ("Duration"), "CoreTracks.Duration", typeof(TimeSpanQueryValue),
+            "duration", "Duration",
+            Catalog.GetString ("Time"), "CoreTracks.Duration", typeof(TimeSpanQueryValue),
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("duration"), Catalog.GetString ("length"), Catalog.GetString ("time"),
             "duration", "length", "time"
         );
 
         public static QueryField MimeTypeField = new QueryField (
-            "mimetype", Catalog.GetString ("Mime Type"), "CoreTracks.MimeType {0} OR CoreTracks.Uri {0}",
+            "mimetype", "MimeType",
+            Catalog.GetString ("Mime Type"), "CoreTracks.MimeType {0} OR CoreTracks.Uri {0}",
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("type"), Catalog.GetString ("mimetype"), Catalog.GetString ("format"), Catalog.GetString ("ext"),
             "type", "mimetype", "format", "ext", "mime"
         );
 
         public static QueryField LastPlayedField = new QueryField (
-            "lastplayed", Catalog.GetString ("Last Played Date"), "CoreTracks.LastPlayedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
+            "lastplayed", "LastPlayed",
+            Catalog.GetString ("Last Played"), "CoreTracks.LastPlayedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("lastplayed"), Catalog.GetString ("played"), Catalog.GetString ("playedon"),
             "lastplayed", "played", "playedon"
         );
 
         public static QueryField LastSkippedField = new QueryField (
-            "lastskipped", Catalog.GetString ("Last Skipped Date"), "CoreTracks.LastSkippedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
+            "lastskipped", "LastSkipped",
+            Catalog.GetString ("Last Skipped"), "CoreTracks.LastSkippedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("lastskipped"), Catalog.GetString ("skipped"), Catalog.GetString ("skippedon"),
             "lastskipped", "skipped", "skippedon"
         );
 
         public static QueryField DateAddedField = new QueryField (
-            "added", Catalog.GetString ("Date Added"), "CoreTracks.DateAddedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
+            "added", "DateAdded",
+            Catalog.GetString ("Date Added"), "CoreTracks.DateAddedStamp", new Type [] {typeof(RelativeTimeSpanQueryValue), typeof(DateQueryValue)},
             // Translators: These are unique search fields.  Please, no spaces. Blank ok.
             Catalog.GetString ("added"), Catalog.GetString ("imported"), Catalog.GetString ("addedon"), Catalog.GetString ("dateadded"), Catalog.GetString ("importedon"),
             "added", "imported", "addedon", "dateadded", "importedon"
         );
 
         public static QueryField PlaylistField = new QueryField (
-            "playlistid", Catalog.GetString ("Playlist"),
+            "playlistid", null, Catalog.GetString ("Playlist"),
             "CoreTracks.TrackID {2} IN (SELECT TrackID FROM CorePlaylistEntries WHERE PlaylistID = {1})", typeof(PlaylistQueryValue),
             "playlistid", "playlist"
         );
 
         public static QueryField SmartPlaylistField = new QueryField (
-            "smartplaylistid", Catalog.GetString ("Smart Playlist"),
+            "smartplaylistid", null, Catalog.GetString ("Smart Playlist"),
             "CoreTracks.TrackID {2} IN (SELECT TrackID FROM CoreSmartPlaylistEntries WHERE SmartPlaylistID = {1})", typeof(SmartPlaylistQueryValue),
             "smartplaylistid", "smartplaylist"
         );
+        
+#endregion
 
         public static QueryFieldSet FieldSet = new QueryFieldSet (
-            ArtistField, AlbumField, DiscField, TitleField, YearField, GenreField, ComposerField, RatingField, PlayCountField,
+            ArtistField, AlbumField, AlbumArtistField, TitleField, TrackNumberField, TrackCountField, DiscField, DiscCountField,
+            YearField, GenreField, ComposerField, ConductorField, GroupingField, CommentField, RatingField, PlayCountField,
             SkipCountField, FileSizeField, UriField, DurationField, MimeTypeField, LastPlayedField, LastSkippedField,
-            DateAddedField, PlaylistField, SmartPlaylistField
+            BpmField, BitRateField, DateAddedField, PlaylistField, SmartPlaylistField
         );
 
-        private const string default_sort = "CoreArtists.NameLowered ASC, CoreAlbums.TitleLowered ASC, CoreTracks.Disc ASC, CoreTracks.TrackNumber ASC, CoreTracks.Uri ASC";
-
+        private const string default_sort = @"CoreAlbums.ArtistNameLowered ASC, CoreAlbums.TitleLowered ASC, CoreTracks.Disc ASC, CoreTracks.TrackNumber ASC";
         public static string GetSort (string key)
         {
             return GetSort (key, false);
@@ -219,66 +330,97 @@ namespace Banshee.Query
         {
             string ascDesc = asc ? "ASC" : "DESC";
             string sort_query = null;
-            switch(key) {
-                case "Track":
+            // TODO use the QueryFields here instead of matching on a string key
+            string column = null;
+            switch (key.ToLower ()) {
+                case "track":
                     sort_query = String.Format (@"
-                        CoreArtists.NameLowered ASC, 
+                        CoreAlbums.ArtistNameLowered ASC, 
                         CoreAlbums.TitleLowered ASC, 
+                        CoreTracks.Disc ASC,
                         CoreTracks.TrackNumber {0}", ascDesc); 
                     break;
 
-                case "Artist":
+                case "albumartist":
+                    sort_query = String.Format (@"
+                        CoreAlbums.ArtistNameLowered {0}, 
+                        CoreAlbums.TitleLowered ASC, 
+                        CoreTracks.Disc ASC,
+                        CoreTracks.TrackNumber ASC", ascDesc); 
+                    break;
+
+                case "artist":
                     sort_query = String.Format (@"
                         CoreArtists.NameLowered {0}, 
                         CoreAlbums.TitleLowered ASC,
                         CoreTracks.Disc ASC,
-                        CoreTracks.TrackNumber ASC,
-                        CoreTracks.Uri ASC", ascDesc); 
+                        CoreTracks.TrackNumber ASC", ascDesc); 
                     break;
 
-                case "Album":
+                case "album":
                     sort_query = String.Format (@"
                         CoreAlbums.TitleLowered {0},
                         CoreTracks.Disc ASC,
-                        CoreTracks.TrackNumber ASC,
-                        CoreTracks.Uri ASC", ascDesc); 
+                        CoreTracks.TrackNumber ASC", ascDesc); 
                     break;
 
-                case "Title":
+                case "title":
                     sort_query = String.Format (@"
                         CoreTracks.TitleLowered {0},
-                        CoreArtists.NameLowered ASC, 
+                        CoreAlbums.ArtistNameLowered ASC, 
                         CoreAlbums.TitleLowered ASC", ascDesc); 
                     break;
 
-                case "Random":
+                case "random":
                     sort_query = "RANDOM ()";
                     break;
 
-                case "Year":
-                case "Genre":
-                case "Disc":
-                case "Duration":
-                case "Rating":
-                case "PlayCount":
-                case "SkipCount":
-                case "LastPlayedStamp":
-                case "LastSkippedStamp":
-                case "DateAddedStamp":
-                case "Uri":
-                case "Composer":
+                // FIXME hacks to aid in migration of these sort keys to actually
+                // using the QueryField (or at least their .Names)
+                case "lastplayed":
+                case "lastskipped":
+                    column = String.Format ("{0}stamp", key);
+                    goto case "comment";
+                case "added":
+                    column = "dateaddedstamp";
+                    goto case "comment";
+
+                case "year":
+                case "bitrate":
+                case "bpm":
+                case "conductor":
+                case "grouping":
+                case "trackcount":
+                case "disc":
+                case "disccount":
+                case "genre":
+                case "duration":
+                case "rating":
+                case "playcount":
+                case "skipcount":
+                case "filesize":
+                case "lastplayedstamp":
+                case "lastskippedstamp":
+                case "dateaddedstamp":
+                case "uri":
+                case "mimetype":
+                case "composer":
+                case "comment":
                     sort_query = String.Format (
                         "CoreTracks.{0} {1}, {2}",
-                        key, ascDesc, default_sort
+                        column ?? key, ascDesc, default_sort
                     );
                     break;
+                default:
+                    Hyena.Log.ErrorFormat ("Unknown sort key passed in! {0} not recognized", key);
+                    break;
             }
             return sort_query;
         }
 
-        private static QueryOrder CreateQueryOrder (string name, bool asc, string label)
+        private static QueryOrder CreateQueryOrder (string name, bool asc, string label, QueryField field)
         {
-            return new QueryOrder (CreateOrderName (name, asc), label, GetSort (name, asc));
+            return new QueryOrder (CreateOrderName (name, asc), label, GetSort (name, asc), field);
         }
 
         public static QueryLimit FindLimit (string name)
@@ -309,34 +451,5 @@ namespace Banshee.Query
         {
             return String.Format ("{0}-{1}", name, asc ? "ASC" : "DESC");
         }
-
-        static BansheeQuery () {
-            // Set translated names for operators
-            IntegerQueryValue.Equal.Label            = Catalog.GetString ("is");
-            IntegerQueryValue.NotEqual.Label         = Catalog.GetString ("is not");
-            IntegerQueryValue.LessThanEqual.Label    = Catalog.GetString ("at most");
-            IntegerQueryValue.GreaterThanEqual.Label = Catalog.GetString ("at least");
-            IntegerQueryValue.LessThan.Label         = Catalog.GetString ("less than");
-            IntegerQueryValue.GreaterThan.Label      = Catalog.GetString ("more than");
-
-            //DateQueryValue.Equal.Label               = Catalog.GetString ("is");
-            //DateQueryValue.NotEqual.Label            = Catalog.GetString ("is not");
-            //DateQueryValue.LessThanEqual.Label       = Catalog.GetString ("at most");
-            //DateQueryValue.GreaterThanEqual.Label    = Catalog.GetString ("at least");
-            DateQueryValue.LessThan.Label            = Catalog.GetString ("before");
-            DateQueryValue.GreaterThan.Label         = Catalog.GetString ("after");
-
-            RelativeTimeSpanQueryValue.GreaterThan.Label         = Catalog.GetString ("more than");
-            RelativeTimeSpanQueryValue.LessThan.Label            = Catalog.GetString ("less than");
-            RelativeTimeSpanQueryValue.GreaterThanEqual.Label    = Catalog.GetString ("at least");
-            RelativeTimeSpanQueryValue.LessThanEqual.Label       = Catalog.GetString ("at most");
-
-            StringQueryValue.Equal.Label             = Catalog.GetString ("is");
-            StringQueryValue.NotEqual.Label          = Catalog.GetString ("is not");
-            StringQueryValue.Contains.Label          = Catalog.GetString ("contains");
-            StringQueryValue.DoesNotContain.Label    = Catalog.GetString ("doesn't contain");
-            StringQueryValue.StartsWith.Label        = Catalog.GetString ("starts with");
-            StringQueryValue.EndsWith.Label          = Catalog.GetString ("ends with");
-        }
     }
 }
