@@ -28,6 +28,8 @@
 
 using System;
 
+using Mono.Unix;
+
 using Hyena.Query;
 using Banshee.Query;
 using Banshee.Sources;
@@ -36,14 +38,40 @@ using Banshee.SmartPlaylist;
 
 namespace Banshee.Dap
 {
-    public abstract class MediaGroupSource : SmartPlaylistSource, IDiskUsageReporter
+    public abstract class MediaGroupSource : SmartPlaylistSource
     {
         private DapSource parent;
         
         public MediaGroupSource (DapSource parent, string name) : base (name, parent.DbId)
         {
             this.parent = parent;
+            
+            Properties.Set<Gtk.Widget> ("Nereid.SourceContents.FooterWidget", 
+                parent.Properties.Get<Gtk.Widget> ("Nereid.SourceContents.FooterWidget"));
+            
+            Properties.Set<string> ("DeleteTracksFromDriveActionLabel", 
+                String.Format (Catalog.GetString ("Delete From {0}"), parent.Name));
         }
+
+        protected override void AfterInitialized ()
+        {
+            base.AfterInitialized ();
+            Reload ();
+        }
+        
+        protected override void OnUpdated ()
+        {
+            base.OnUpdated ();
+            if (parent != null) {
+                parent.RaiseUpdated ();
+            }
+        }
+
+
+        /*public override bool AcceptsInputFromSource (Source source)
+        {
+            return (source is DatabaseSource) && source.Parent != Parent && source != Parent;
+        }*/
         
         public override string ConditionSql {
             get { return base.ConditionSql; }
@@ -66,11 +94,7 @@ namespace Banshee.Dap
         }
 
         public long BytesUsed {
-            get { return parent.BytesUsed; }
-        }
-
-        public long BytesCapacity {
-            get { return parent.BytesCapacity; }
+            get { return DatabaseTrackModel.UnfilteredFileSize; }
         }
     }
 }
