@@ -43,13 +43,17 @@ namespace Hyena.Data.Gui
                 (uint)TargetType.ModelSelection);
     }
     
-    public partial class ListView<T> : Container
+    public partial class ListView<T> : ListViewBase
     {
         private static TargetEntry [] drag_drop_dest_entries = new TargetEntry [] {
             ListViewDragDropTarget.ModelSelection
         };
         
-        protected static TargetEntry [] DragDropDestEntries {
+        protected virtual TargetEntry [] DragDropDestEntries {
+            get { return drag_drop_dest_entries; }
+        }
+
+        protected virtual TargetEntry [] DragDropSourceEntries {
             get { return drag_drop_dest_entries; }
         }
         
@@ -94,7 +98,7 @@ namespace Hyena.Data.Gui
         {
             if (ForceDragSourceSet || Reorderable) {
                 Gtk.Drag.SourceSet (this, Gdk.ModifierType.Button1Mask | Gdk.ModifierType.Button3Mask, 
-                    DragDropDestEntries, Gdk.DragAction.Copy | Gdk.DragAction.Move);
+                    DragDropSourceEntries, Gdk.DragAction.Copy | Gdk.DragAction.Move);
             } else {
                 Gtk.Drag.SourceUnset (this);
             }
@@ -117,33 +121,36 @@ namespace Hyena.Data.Gui
             }
         }
         
+        private void OnDragScroll (GLib.TimeoutHandler handler, double threshold, int total, int position)
+        {
+            if (position < threshold) {
+                drag_scroll_velocity = -1.0 + (position / threshold);
+            } else if (position > total - threshold) {
+                drag_scroll_velocity = 1.0 - ((total - position) / threshold);
+            } else {
+                StopDragScroll ();
+                return;
+            }
+            
+            if (drag_scroll_timeout_id == 0) {
+                drag_scroll_timeout_id = GLib.Timeout.Add (drag_scroll_timeout_duration, handler);
+            }
+        }
+        
         protected override bool OnDragMotion (Gdk.DragContext context, int x, int y, uint time)
         {
             if (!Reorderable) {
                 StopDragScroll ();
                 drag_reorder_row_index = -1;
                 drag_reorder_motion_y = -1;
-                InvalidateListWindow ();
+                InvalidateList ();
                 return false;
             }
             
             drag_reorder_motion_y = y;
             DragReorderUpdateRow ();
             
-            double scroll_threshold = Allocation.Height * 0.3;
-            
-            if (y < scroll_threshold) {
-                drag_scroll_velocity = -1.0 + (y / scroll_threshold);
-            } else if (y > Allocation.Height - scroll_threshold) {
-                drag_scroll_velocity = 1.0 - ((Allocation.Height - y) / scroll_threshold);
-            } else {
-                StopDragScroll ();
-                return true;
-            }
-            
-            if (drag_scroll_timeout_id == 0) {
-                drag_scroll_timeout_id = GLib.Timeout.Add (drag_scroll_timeout_duration, OnDragScrollTimeout);
-            }
+            OnDragScroll (OnDragVScrollTimeout, Allocation.Height * 0.3, Allocation.Height, y);
             
             return true;
         }
@@ -158,22 +165,39 @@ namespace Hyena.Data.Gui
             StopDragScroll ();
             drag_reorder_row_index = -1;
             drag_reorder_motion_y = -1;
+            InvalidateList ();
         }
         
-        private bool OnDragScrollTimeout ()
+        private bool OnDragVScrollTimeout ()
         {
-            ScrollTo (vadjustment.Value + (drag_scroll_velocity * drag_scroll_velocity_max));
+            ScrollTo (VadjustmentValue + (drag_scroll_velocity * drag_scroll_velocity_max));
             DragReorderUpdateRow ();
             return true;
         }
         
         private void DragReorderUpdateRow ()
         {
-            int row = GetRowAtY (drag_reorder_motion_y + list_alloc.Y) - 1;
+            int row = GetDragRow (drag_reorder_motion_y);
             if (row != drag_reorder_row_index) {
                 drag_reorder_row_index = row;
-                InvalidateListWindow ();
+                InvalidateList ();
             }   
         }
+        
+        protected int GetDragRow (int y)
+        {
+            y = TranslateToListY (y);
+            int row = GetRowAtY (y);
+            
+            if (row == -1) {
+                return -1;
+            }
+
+            if (row != GetRowAtY (y + RowHeight / 2)) {
+                row++;
+            }
+
+            return row;
+        }
     }
-}
+}
\ No newline at end of file
